==> haskell-stringbuilder-0.5.1-586-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-KjhYwQ3QAlM1pJ26nRhIIn
key:                  stringbuilder-0.5.1-KjhYwQ3QAlM1pJ26nRhIIn
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  d0743d26b7ad462ebcd03d0de2829ca0
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringbuilder
hs-libraries:         HSstringbuilder-0.5.1-KjhYwQ3QAlM1pJ26nRhIIn
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringbuilder-0.5.1-587-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-Bz36guGIZzdFwYU15cEXhS
key:                  stringbuilder-0.5.1-Bz36guGIZzdFwYU15cEXhS
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  9f4631e575bf8bd031ce19e5006c9145
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringbuilder
hs-libraries:         HSstringbuilder-0.5.1-Bz36guGIZzdFwYU15cEXhS
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
